@@ -3,7 +3,7 @@ package Hades;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 use Module::Generate;
 use Switch::Again qw/switch/;
 use Hades::Myths { as_keywords => 1 };
@@ -1323,7 +1323,7 @@ Hades - Less is more, more is less!
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
@@ -1332,7 +1332,16 @@ Version 0.19
 	use Hades;
 
 	Hades->run({
-		eval => 'Kosmos { [penthos curae] :t(Int) :d(2) :p :pr :c :r geras $nosoi :t(Int) :d(2) { if (£penthos == $nosoi) { return £curae; } } }'
+		eval => q|
+			Kosmos { 
+				[penthos curae] :t(Int) :d(2) :p :pr :c :r 
+				geras $nosoi :t(Int) :d(2) { 
+					if (£penthos == $nosoi) {
+						return £curae; 
+					}
+				}
+			}
+		|
 	});
 
 	... generates ...
@@ -2058,7 +2067,7 @@ Used in conjunction with Dict and Tuple to specify slots that are optional and m
 
 =head2 Macros
 
-Hades has a concept of macros that allow you to write re-usable code. see L<https://metacpan.org/source/LNATION/Hades-0.19/macro-fh.hades> for an example of how to extend via macros.
+Hades has a concept of macros that allow you to write re-usable code. see L<https://metacpan.org/source/LNATION/Hades-0.20/macro-fh.hades> for an example of how to extend via macros.
 
 	macro {
 		FH [ macro => [qw/read_file write_file/], alias => { read_file => [qw/rf/], write_file => [qw/wf/] } ]
